Spot Websocket Streams
======================


Aggregate Trade Streams
-----------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.agg_trade

Trade Streams
-------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.trade

Kline/Candlestick Streams
-------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.kline

Kline/Candlestick Streams with timezone offset
----------------------------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.kline_timezone_offset

Individual symbol or all symbols mini ticker
--------------------------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.mini_ticker

Individual symbol or all symbols ticker
---------------------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.ticker

Individual symbol or all book ticker
------------------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.book_ticker

Individual Symbol Rolling Window Statistics Streams
---------------------------------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.rolling_window_ticker

All Market Rolling Window Statistics Streams
--------------------------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.rolling_window_ticker_all_symbols

Partial Book Depth Streams
--------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.partial_book_depth

Diff. Depth Stream
------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.diff_book_depth

Listen to user data by provided listenkey
-----------------------------------------
.. autofunction:: binance.websocket.spot.websocket_stream.SpotWebsocketStreamClient.user_data
